@@ -82,18 +82,21 @@ pub(crate) async fn verify_message_from_provider<'a, F: RequestFilterExecutor>(
   }
 }
 
-pub fn display_message_result(
+pub fn process_message_result(
   interaction: &Message,
-  match_result: &Result<Option<String>, MismatchResult>) {
+  match_result: &Result<Option<String>, MismatchResult>,
+  output: &mut Vec<String>) {
   match match_result {
     Ok(_) => {
-      display_result(Green.paint("OK"),
-        interaction.metadata.iter()
-          .map(|(k, v)| (k.clone(), serde_json::to_string(&v.clone()).unwrap_or_default(), Green.paint("OK"))).collect());
+      generate_display_for_result(Green.paint("OK"),
+                                  interaction.metadata.iter()
+          .map(|(k, v)| (k.clone(), serde_json::to_string(&v.clone()).unwrap_or_default(), Green.paint("OK"))).collect(),
+                                  output
+      );
     },
     Err(ref err) => match *err {
       MismatchResult::Error(ref err_des, _) => {
-        println!("      {}", Red.paint(format!("Request Failed - {}", err_des)));
+        output.push(format!("      {}", Red.paint(format!("Request Failed - {}", err_des))));
       },
       MismatchResult::Mismatches { ref mismatches, .. } => {
         let metadata_results = interaction.metadata.iter().map(|(k, v)| {
@@ -115,22 +118,26 @@ pub fn display_message_result(
           Green.paint("OK")
         };
 
-        display_result(body_result, metadata_results);
+        generate_display_for_result(body_result, metadata_results, output);
       }
     }
   }
 }
 
-fn display_result(body_result: ANSIGenericString<str>, metadata_result: Vec<(String, String, ANSIGenericString<str>)>) {
-  println!("    generates a message which");
+fn generate_display_for_result(
+  body_result: ANSIGenericString<str>,
+  metadata_result: Vec<(String, String, ANSIGenericString<str>)>,
+  output: &mut Vec<String>
+) {
+  output.push("    generates a message which".to_string());
   if !metadata_result.is_empty() {
-    println!("      includes metadata");
+    output.push("      includes metadata".to_string());
     for (key, value, result) in metadata_result {
-      println!("        \"{}\" with value {} ({})", Style::new().bold().paint(key),
-        Style::new().bold().paint(value), result);
+      output.push(format!("        \"{}\" with value {} ({})", Style::new().bold().paint(key),
+        Style::new().bold().paint(value), result));
     }
   }
-  println!("      has a matching body ({})", body_result);
+  output.push(format!("      has a matching body ({})", body_result));
 }
 
 fn extract_metadata(actual_response: &HttpResponse) -> HashMap<String, Value> {
