@@ -352,28 +352,28 @@ impl HALClient {
     }
 
     fn parse_link_url(self, link: &Link, values: &HashMap<String, String>) -> Result<String, PactBrokerError> {
-        match link.href {
-            Some(ref href) => {
-                log::debug!("templated URL = {}", href);
-                let re = Regex::new(r"\{(\w+)\}").unwrap();
-                let final_url = re.replace_all(href, |caps: &Captures| {
-                    let lookup = caps.get(1).unwrap().as_str();
-                    log::debug!("Looking up value for key '{}'", lookup);
-                    match values.get(lookup) {
-                        Some(val) => val.clone(),
-                        None => {
-                            log::warn!("No value was found for key '{}', mapped values are {:?}",
-                                lookup, values);
-                            format!("{{{}}}", lookup)
-                        }
-                    }
-                });
-                log::debug!("final URL = {}", final_url);
-                Ok(final_url.to_string())
-            },
-            None => Err(PactBrokerError::LinkError(format!("Expected a HAL+JSON response from the pact broker, but got a link with no HREF. URL: '{}', LINK: '{}'",
-                self.url, link.name)))
-        }
+      match link.href {
+        Some(ref href) => {
+          debug!("templated URL = {}", href);
+          let re = Regex::new(r"\{(\w+)}").unwrap();
+          let final_url = re.replace_all(href, |caps: &Captures| {
+            let lookup = caps.get(1).unwrap().as_str();
+            trace!("Looking up value for key '{}'", lookup);
+            match values.get(lookup) {
+              Some(val) => urlencoding::encode(val.as_str()).to_string(),
+              None => {
+                warn!("No value was found for key '{}', mapped values are {:?}", lookup, values);
+                format!("{{{}}}", lookup)
+              }
+            }
+          });
+          debug!("final URL = {}", final_url);
+          Ok(final_url.to_string())
+        },
+        None => Err(PactBrokerError::LinkError(
+          format!("Expected a HAL+JSON response from the pact broker, but got a link with no HREF. URL: '{}', LINK: '{}'",
+          self.url, link.name)))
+      }
     }
 
   /// Iterate over all the links by name
@@ -989,6 +989,8 @@ pub struct ConsumerVersionSelector {
   pub main_branch: Option<bool>,
   /// Applications with the given branch
   pub branch: Option<String>,
+  /// Applications that match the the provider version branch sent during verification
+  pub matching_branch: Option<bool>,
 }
 
 #[derive(Serialize, Deserialize, Debug, Clone)]
@@ -1260,6 +1262,15 @@ mod tests {
     expect!(client.clone().parse_link_url(&link, &values)).to(be_ok().value("http://A/{valC}"));
   }
 
+  #[test]
+  fn parse_link_url_encodes_the_tokens_in_href() {
+    let client = HALClient::default();
+    let values = hashmap!{ "valA".to_string() => "A".to_string(), "valB".to_string() => "B/C".to_string() };
+
+    let link = Link { name: "link".to_string(), href: Some("http://{valA}/{valB}".to_string()), templated: false, title: None };
+    expect!(client.clone().parse_link_url(&link, &values)).to(be_ok().value("http://A/B%2FC"));
+  }
+
     #[tokio::test]
     async fn fetch_link_returns_an_error_if_a_previous_resource_has_not_been_fetched() {
         let client = HALClient::with_url("http://localhost", None);
@@ -1689,6 +1700,7 @@ mod tests {
         deployed: None,
         released: None,
         main_branch: None,
+        matching_branch: None,
         environment: None,
       }), None).await;
 
@@ -1788,6 +1800,7 @@ mod tests {
       deployed: None,
       released: None,
       main_branch: None,
+      matching_branch: None,
       environment: None,
     }), None).await;
 
